@@ -9,11 +9,17 @@ All rights reserved.
 For detailed copyright information see the file COPYING in
 the root of the distribution archive.
 """
+from __future__ import division
+from future import standard_library
+standard_library.install_aliases()
+from builtins import range
+from past.utils import old_div
+from builtins import object
 
 import os
 import re
 import string
-import urllib
+import urllib.request, urllib.parse, urllib.error
 import pefile
 
 __author__ = 'Ero Carrera'
@@ -23,7 +29,7 @@ __contact__ = 'ero.carrera@gmail.com'
 
 
 
-class SignatureDatabase:
+class SignatureDatabase(object):
     """This class loads and keeps a parsed PEiD signature database.
 
     Usage:
@@ -195,7 +201,7 @@ class SignatureDatabase:
             #
             try :
                 data = pe.__data__
-            except Exception, excp :
+            except Exception as excp :
                 raise
 
             # Load the corresponding tree of signatures
@@ -213,7 +219,7 @@ class SignatureDatabase:
             #
             try :
                 data = pe.get_memory_mapped_image()
-            except Exception, excp :
+            except Exception as excp :
                 raise
 
             # Load the corresponding tree of signatures
@@ -235,7 +241,7 @@ class SignatureDatabase:
 
             signatures = self.signature_tree_eponly_false
 
-            scan_addresses = xrange( len(data) )
+            scan_addresses = range( len(data) )
 
         # For each start address, check if any signature matches
         #
@@ -335,7 +341,7 @@ class SignatureDatabase:
             # it means that a signature in the database
             # ends here and that there's an exact match.
             #
-            if None in match.values():
+            if None in list(match.values()):
                 # idx represent how deep we are in the tree
                 #
                 #names = [idx+depth]
@@ -345,7 +351,7 @@ class SignatureDatabase:
                 # if it has an element other than None,
                 # if not then we have an exact signature
                 #
-                for item in match.items():
+                for item in list(match.items()):
                     if item[1] is None :
                         names.append (item[0])
                 matched_names.append(names)
@@ -353,7 +359,7 @@ class SignatureDatabase:
             # If a wildcard is found keep scanning the signature
             # ignoring the byte.
             #
-            if match.has_key ('??') :
+            if '??' in match :
                 match_tree_alternate = match.get ('??', None)
                 data_remaining = data[idx + 1 :]
                 if data_remaining:
@@ -366,10 +372,10 @@ class SignatureDatabase:
         # If we have any more packer name in the end of the signature tree
         # add them to the matches
         #
-        if match is not None and None in match.values():
+        if match is not None and None in list(match.values()):
             #names = [idx + depth + 1]
             names = list()
-            for item in match.items() :
+            for item in list(match.items()) :
                 if item[1] is None:
                     names.append(item[0])
             matched_names.append(names)
@@ -392,7 +398,7 @@ class SignatureDatabase:
             #
             if not os.path.exists(filename):
                 try:
-                    sig_f = urllib.urlopen(filename)
+                    sig_f = urllib.request.urlopen(filename)
                     sig_data = sig_f.read()
                     sig_f.close()
                 except IOError:
@@ -572,7 +578,7 @@ def is_probably_packed( pe ):
         if s_entropy > 7.4:
             total_compressed_data += s_length
 
-    if ((1.0 * total_compressed_data)/total_pe_data_length) > .2:
+    if (old_div((1.0 * total_compressed_data),total_pe_data_length)) > .2:
         has_significant_amount_of_compressed_data = True
 
     return has_significant_amount_of_compressed_data
